@@ -33,32 +33,6 @@
 void
 sebie_update_view(struct sebie_s *sebie)
 {
-  if (sebie->dirty_tags & SEBIE_UPDATE_SCALED_PIXBUF) {
-    GdkGC *gdkGC = gdk_gc_new(sebie->view.drawingarea1->window);
-    GdkColor color;
-    color.red   = 0xe0e0;
-    color.green = 0xe0e0;
-    color.blue  = 0xe0e0;
-    gdk_gc_set_rgb_fg_color(gdkGC, &color);
-    gdk_draw_rectangle(sebie->view.drawingarea1->window,
-		       gdkGC,
-		       TRUE,
-		       0, 0,
-		       -1, -1);
-    if (sebie->model.scaled_pixbuf != NULL) {
-      gdk_pixbuf_render_to_drawable(sebie->model.scaled_pixbuf,
-				    sebie->view.drawingarea1->window,
-				    gdkGC,
-				    0, 0,
-				    0, 0,
-				    sebie->model.scaled_width,
-				    sebie->model.scaled_height,
-				    GDK_RGB_DITHER_NONE,
-				    0,
-				    0);
-    }
-  }
-  
   if (sebie->dirty_tags & SEBIE_UPDATE_SELECTION_FAC) {
     gchar buf[6];
     sebie->model.selection_fac = (double)sebie->model.selection_fac_width / (double) sebie->model.selection_fac_height;
@@ -84,8 +58,25 @@ sebie_update_view(struct sebie_s *sebie)
     gtk_entry_set_text(GTK_ENTRY(sebie->view.entry_selection_gamma), buf);
   }
 
-  if (sebie->dirty_tags & SEBIE_UPDATE_SELECTION_RECT) {
+  if (sebie->dirty_tags & SEBIE_UPDATE_SCALED_PIXBUF ||
+      sebie->dirty_tags & SEBIE_UPDATE_SELECTION_RECT) {
+    /* do it the rough way, always draw the whole area and not just the
+     * areas which changed  */
     GdkGC *gdkGC = gdk_gc_new(sebie->view.drawingarea1->window);
+    
+    if (sebie->dirty_tags & SEBIE_UPDATE_SCALED_PIXBUF) {
+      GdkColor color;
+      color.red   = 0xe0e0;
+      color.green = 0xe0e0;
+      color.blue  = 0xe0e0;
+      gdk_gc_set_rgb_fg_color(gdkGC, &color);
+      gdk_draw_rectangle(sebie->view.drawingarea1->window,
+			 gdkGC,
+			 TRUE,
+			 0, 0,
+			 -1, -1);
+    }
+    
     if (sebie->model.scaled_pixbuf != NULL) {
       gdk_pixbuf_render_to_drawable (sebie->model.scaled_pixbuf,
 				     sebie->view.drawingarea1->window,
@@ -288,25 +279,25 @@ rotate_scaled(struct sebie_s *sebie, int direction)
 void
 apply_gamma(struct sebie_s *sebie)
 {
-  GdkPixbuf *corr = pixbuf_color_corrections(sebie->model.scaled_pixbuf_orig,
-					     sebie->model.image_gamma);
-
-  if (sebie->model.scaled_pixbuf != NULL) {
+  if (sebie->model.scaled_pixbuf_orig != NULL &&
+      sebie->model.scaled_pixbuf != NULL) {
+    GdkPixbuf *corr = pixbuf_color_corrections(sebie->model.scaled_pixbuf_orig,
+					       sebie->model.image_gamma);
     g_object_unref(sebie->model.scaled_pixbuf);
-  }
-  
-  if (sebie->model.scaled_rotation == SEBIE_ROTATE_000) {
-    sebie->model.scaled_pixbuf = corr;
-  } else {
-    GdkPixbuf *rotated = rotate_pixbuf(corr, sebie->model.scaled_rotation);
-    if (corr != NULL) {
-      g_object_unref(corr);
+    
+    if (sebie->model.scaled_rotation == SEBIE_ROTATE_000) {
+      sebie->model.scaled_pixbuf = corr;
+    } else {
+      GdkPixbuf *rotated = rotate_pixbuf(corr, sebie->model.scaled_rotation);
+      if (corr != NULL) {
+	g_object_unref(corr);
+      }
+      sebie->model.scaled_pixbuf = rotated;
     }
-    sebie->model.scaled_pixbuf = rotated;
+    
+    sebie->dirty_tags |= SEBIE_UPDATE_SCALED_PIXBUF;
+    sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
   }
-  
-  sebie->dirty_tags |= SEBIE_UPDATE_SCALED_PIXBUF;
-  sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
   sebie_update_view(sebie);
 }
 
