@@ -289,6 +289,17 @@ on_entry_selection_gamma_changed (GtkEditable *editable,
   apply_gamma(sebie);
 }
 
+gboolean
+on_drawingarea1_expose_event (GtkWidget       *widget,
+			      GdkEventExpose  *event,
+			      gpointer         user_data)
+{
+  struct sebie_s *sebie = (struct sebie_s *)user_data;
+  sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
+  sebie_update_view(sebie);
+  return FALSE;
+}
+
 gboolean
 on_drawingarea1_button_press_event     (GtkWidget       *widget,
                                         GdkEventButton  *event,
