@@ -71,6 +71,11 @@ void
 on_entry_selection_gamma_changed (GtkEditable *editable,
 				  gpointer  user_data);
 
+gboolean
+on_drawingarea1_expose_event (GtkWidget       *widget,
+			      GdkEventExpose  *event,
+			      gpointer         user_data);
+
 gboolean
 on_drawingarea1_button_press_event     (GtkWidget       *widget,
                                         GdkEventButton  *event,
