@@ -19,9 +19,14 @@
  *
  */
 #include "sebie_config.h"
+
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
+
 #include <stdio.h>
 #include <errno.h>
 #include <string.h>
+#include <stdlib.h>
 
 
 #define BUF_LEN 1024
@@ -45,6 +50,9 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
     case CONFIG_INTEGER:
       *spec[i].storage.integer = spec[i].defvalue.integer;
       break;
+    case CONFIG_DOUBLE:
+      *spec[i].storage.doublev = spec[i].defvalue.doublev;
+      break;
     case CONFIG_STRING:
       *spec[i].storage.string = g_strdup(spec[i].defvalue.string);
       break;
@@ -106,9 +114,12 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
 	case CONFIG_INTEGER:
 	  *spec[i].storage.integer = atoi(value);
 	  break;
+	case CONFIG_DOUBLE:
+	  *spec[i].storage.doublev = atof(value);
+	  break;
 	case CONFIG_STRING:
 	  if (*spec[i].storage.string != NULL) {
-	    g_free(*spec[i].storage.string );
+	    g_free(*spec[i].storage.string);
 	  }
 	  *spec[i].storage.string = g_strdup(value);
 	  break;
@@ -143,6 +154,9 @@ sebie_write_config(const char *path, sebie_config_spec *spec)
     case CONFIG_INTEGER:
       fprintf(file, "%s=%d\n", spec[i].name, *spec[i].storage.integer);
       break;
+    case CONFIG_DOUBLE:
+      fprintf(file, "%s=%lf\n", spec[i].name, *spec[i].storage.doublev);
+      break;
     case CONFIG_STRING:
       fprintf(file, "%s=%s\n", spec[i].name, *spec[i].storage.string);
       break;
